xml\_common.utils package
=========================

CamelCase Enum
--------------

This implementation of the `Enum Python Class <https://docs.python.org/3/library/enum.html>`_ supports the conversation from EML types to Python Enum.

.. automodule:: xml_common.utils.enum
   :members:
   :undoc-members:
   :show-inheritance:

Language Class
--------------

Language type for various EML objects.

.. automodule:: xml_common.utils.language
   :members:
   :undoc-members:
   :show-inheritance:

Defined Values
--------------

These are helpful predefined types.

.. automodule:: xml_common.utils.length_unit
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: xml_common.utils.establishment_means
   :members:
   :undoc-members:
   :show-inheritance:

Type Function
-------------

Functions for type conversion, from XML defined to Python data types.

.. automodule:: xml_common.utils.type_functions
   :members:
   :undoc-members:
   :show-inheritance:

Iteration
---------

Iteration functions.

`OptionalTqdm` support having `tqdm <https://tqdm.github.io/>`_ installed or not.

.. automodule:: xml_common.utils.iteratate
   :members:
   :undoc-members:
   :show-inheritance:

GPolygon
--------

GPolygon support functions.

.. automodule:: xml_common.utils.gpolygon
   :members:
   :undoc-members:
   :show-inheritance:
